| Title: | Return equilibrium solution to malaria transmission model |
|---|---|
| Description: | Often we are interested in the state of a given malaria transmission model at equibrium. However, some models (e.g. the Griffin et al. 2014 model) are quite complex, and can result in equilibrium solutions that are fairly in-depth. In these situations it is useful to have a "canonical" equilibrium solution that is tried and tested, and can be used reliably by multiple users. This package aims to be a place for hosting these canonical solutions, and for storing useful tests, checks and plotting functions for exploring a given solution. |
| Authors: | Bob Verity [aut, cre], Pete Winskill [aut], Giovanni Charles [aut] |
| Maintainer: | Bob Verity <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.1 |
| Built: | 2026-05-22 18:49:00 UTC |
| Source: | https://github.com/mrc-ide/malariaEquilibrium |
Return node values and weights from Gaussian quadrature of normal distribution with n nodes.
gq_normal(n)gq_normal(n)
n |
number of nodes |
Returns the equilibrium states for the model of Griffin et al. (2014). A derivation of the equilibrium solutions can be found in Griffin (2016). Integrates over the distribution of biting heterogeneity using Gaussian quadrature.
human_equilibrium(EIR, ft, p, age, h = gq_normal(10))human_equilibrium(EIR, ft, p, age, h = gq_normal(10))
EIR |
EIR for adults, in units of infectious bites per person per year |
ft |
proportion of clinical cases effectively treated |
p |
vector of model parameters |
age |
vector of age groups, in units of years |
h |
a list of Gauss-Hermite nodes and associated weights, used for
integrating over heterogeneity in biting. See |
Griffin et. al. (2014). Estimates of the changing age-burden of Plasmodium falciparum malaria disease in sub-Saharan Africa. doi:10.1038/ncomms4136
Griffin (2016). Is a reproduction number of one a threshold for Plasmodium falciparum malaria elimination? doi:10.1186/s12936-016-1437-9 (see supplementary material)
Returns the equilibrium states for the model of Griffin et al. (2014). A derivation of the equilibrium solutions can be found in Griffin (2016).
This function does not account for biting heterogeneity - see
human_equilibrium() for function that takes this into account.
human_equilibrium_no_het(EIR, ft, p, age)human_equilibrium_no_het(EIR, ft, p, age)
EIR |
EIR for adults, in units of infectious bites per person per year |
ft |
proportion of clinical cases effectively treated |
p |
vector of model parameters |
age |
vector of age groups, in units of years |
Griffin et. al. (2014). Estimates of the changing age-burden of Plasmodium falciparum malaria disease in sub-Saharan Africa. doi:10.1038/ncomms4136
Griffin (2016). Is a reproduction number of one a threshold for Plasmodium falciparum malaria elimination? doi:10.1186/s12936-016-1437-9 (see supplementary material)
Parameter sets are stored within the package inst/extdata folder. Load one of these sets by name.
load_parameter_set(file_name = "Jamie_parameters.rds")load_parameter_set(file_name = "Jamie_parameters.rds")
file_name |
the name of a parameter set within the inst/extdata folder. |
Load and return file from within the inst folder of this package.
malariaEq_file(name)malariaEq_file(name)
name |
name of file |
Often we are interested in the state of a given malaria transmission model at equibrium. However, some models (e.g. the Griffin et al. 2014 model) are quite complex, and can result in equilibrium solutions that are fairly in-depth. In these situations it is useful to have a "canonical" equilibrium solution that is tried and tested, and can be used reliably by multiple users. This package aims to be a place for hosting these canonical solutions, and for storing useful tests, checks and plotting functions for exploring a given solution.